@@ -37,14 +37,11 @@ class MainWindow(QtGui.QMainWindow):
                 os.makedirs("/home/user/MyDocs/.Quizzynator/")
             except:
                 pass  
-           
             self.richtigsound="/opt/quizzynator/richtig.wav"
             self.falschsound="/opt/quizzynator/falsch.wav"
             self.gameoversound="/opt/quizzynator/gameover.wav"
             self.rankupsound="/opt/quizzynator/rankup.wav"
-	    self.savegame="/home/user/MyDocs/.Quizzynator/quizzynator.db"
-           
-            #self.fragenkatalog="/home/user/MyDocs//fragenkatalog.py"      
+            self.savegame="/home/user/MyDocs/.Quizzynator/quizzynator.db"   
             self.highscoredatenbank="/home/user/MyDocs/.QuizzyNator/highscores.db"
 #Pfade PC:
         else:
@@ -53,10 +50,10 @@ class MainWindow(QtGui.QMainWindow):
             self.richtigsound="richtig.wav"
             self.falschsound="falsch.wav"
             self.gameoversound="gameover.wav"
-            self.rankupsound="rankup.wav"
-            
+            self.rankupsound="rankup.wav"  
             self.highscoredatenbank="highscores.db"
             self.versionspfad="version.ini"
+            self.savegame="quizzynator.db"
 #Phonon initiieren
 
         self.m_media = Phonon.MediaObject(self)
@@ -387,19 +384,15 @@ class MainWindow(QtGui.QMainWindow):
     def save_settings(self):
 #Funktionsname outdated.Hier wird der Spielstand gespeichert.Derzeit klappt das nur, wenn man die Applikation im Fullscreenmode laufen lässt und auf Beenden klickt
 #Ein klick auf X zeigt keine wirkung
-        playername=self.ui.playername.text()
-     
         default=open(self.savegame,"w")
                
-        userdata={"Spielername":str(playername),
+        userdata={"Spielername":str(self.spielername),
                   "Score":str(self.score),
                   "Niederlagen":str(self.niederlagencounter)}
                 
         for data in userdata:
             default.write(data+" " + userdata[data]+"\n")
         default.close()
-                 
-     
     def save_highscore(self):    
 #Highscore speichern
         if os.path.isfile(self.highscoredatenbank):
@@ -486,7 +479,7 @@ class MainWindow(QtGui.QMainWindow):
         
     def craveobrowser(self):
         webbrowser.open("http://www.craveo.de")
-		
+        
 #Möglichkeit, eigene Fragen einzureichen       
     def fragen_einreichen(self):
         self.ui.stackedWidget.setCurrentIndex(5)
